import { useEffect, useState } from 'react';
import useSDKFactory from './useSDKFactory';
import { PassListenable, UseCase, RRListenable, SRListenable, } from '@inkerlabs/sdk';
export default function useContractDataFactory(useCase) {
    return function useContractData() {
        var sdk = useSDKFactory()();
        var _a = useState(undefined), infos = _a[0], setInfos = _a[1];
        var _b = useState(undefined), error = _b[0], setError = _b[1];
        var id;
        var cb = function (err, _infos) {
            setError(err);
            setInfos(_infos);
        };
        var unlisten = function () {
            switch (useCase) {
                case UseCase.PASS:
                    var passSDK = sdk;
                    if (id) {
                        passSDK.unlisten(id, PassListenable.CONTRACT_INFOS);
                    }
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    if (id) {
                        rrSDK.unlisten(id, RRListenable.CONTRACT);
                    }
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    if (id) {
                        srSDK.unlisten(id, SRListenable.CONTRACT_INFOS);
                    }
                    break;
                default:
                    throw new Error("Unknown use case ".concat(useCase));
            }
        };
        useEffect(function () {
            unlisten();
            switch (useCase) {
                case UseCase.PASS:
                    var passSDK = sdk;
                    id = passSDK.listen(PassListenable.CONTRACT_INFOS, cb);
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    id = rrSDK.listen(RRListenable.CONTRACT, cb);
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    id = srSDK.listen(SRListenable.CONTRACT_INFOS, cb);
                    break;
                default:
                    throw new Error("Unknown use case ".concat(useCase));
            }
        }, []);
        // Emulate componentWillUnmount
        useEffect(function () {
            return function () {
                unlisten();
            };
        }, []);
        return [infos, error];
    };
}
